==> groupoffice-com-4.0.47.tar.gz: groupoffice-com-4.0.47/modules/email/language/de.php <==
<?php

$l["forwardTo"]='Nachricht weiterleiten an';
$l["messages"]='Nachrichten';
$l["message"]='Nachricht';
$l["inbox"]='Eingang';
$l["accounts"]='E-Mail-Konten';
$l["account"]='E-Mail-Konto';
$l["crossAccountMove"]='Es ist nicht möglich, Nachrichten von einem zu einem anderen E-Mail-Konto zu verschieben!';
$l["compose"]='Erstellen';
$l["reply"]='Antworten';
$l["replyAll"]='Allen antworten';
$l["forward"]='Weiterleiten';
$l["markAsRead"]='Als gelesen markieren';
$l["markAsUnread"]='Als ungelesen markieren';
$l["flag"]='Markierung hinzufügen';
$l["unflag"]='Markierung löschen';
$l["flagged"]='Markiert';
$l["unflagged"]='Unmarkiert';
$l["root"]='/';
$l["folders"]='Ordner';
$l["filter"]='Regel';
$l["filters"]='Regeln';
$l["selectFolderDelete"]='Markieren Sie den Ordner, der gelöscht werden soll';
$l["selectFolderAdd"]='Markieren Sie aus der Liste einen Ordner, dem ein Unterordner hinzufügt werden soll. Klicken Sie dann auf \'Neuen Ordner erstellen\'';
$l["selectFolderRename"]='Markieren Sie den Ordner, der umbenannt werden soll';
$l["forward"]='Weiterleiten';
$l["resetSearch"]='Suche zurücksetzen';
$l["emailMessage"]='Nachricht';
$l["host"]='Host';
$l["field"]='Kopfzeile';
$l["contains"]='Enthält';
$l["moveToFolder"]='Verschiebe nach';
$l["incomingMail"]='Posteingang';
$l["advanced"]='Erweitert';
$l["ssl"]='SSL';
$l["tls"]='TLS';
$l["novalidateCert"]='Zertifikat nicht überprüfen';
$l["port"]='Port';
$l["rootMailbox"]='Root (/)';
$l["manageFolders"]='Ordner verwalten';
$l["sendItemsFolder"]='Gesendet';
$l["trashFolder"]='Papierkorb';
$l["draftsFolder"]='Entwürfe ';
$l["sender"]='Von';
$l["subject"]='Betreff';
$l["toField"]='An';
$l["ccField"]='CC';
$l["bccField"]='BCC';
$l["keyword"]='Enthält';
$l["notification"]='Lesebestätigung anfordern';
$l["high"]='Hoch';
$l["normal"]='Normal';
$l["low"]='Niedrig';
$l["from"]='Von';
$l["sendTo"]='Empfänger';
$l["cc"]='CC';
$l["bcc"]='BCC';
$l["selectTemplate"]='Vorlage auswählen';
$l["composeEmail"]='Nachricht schreiben';
$l["send"]='Senden';
$l["extraOptions"]='Zusatzoptionen';
$l["attachments"]='Anhänge';
$l["show"]='Ansicht';
$l["noAccount"]='Sie haben kein E-Mail-Konto konfiguriert. Gehen Sie auf Administration -> E-Mail-Konten, um dies nachzuholen';
$l["attachFiles"]='Dateien anhängen';
$l["uploadAttachments"]='Anhänge hochladen';
$l["startTransfer"]='Transfer beginnen';
$l["cantEditFolder"]='Sie können diesen Ordner nicht bearbeiten';
$l["cantDeleteInboxFolder"]='Sie können den Ordner INBOX (/) nicht löschen';
$l["cantRenameInboxFolder"]='Sie können den Ordner INBOX (/) nicht umbenennen';
$l["enterFolderName"]='Geben Sie einen Ordnernamen ein:';
$l["addFolder"]='Neuen Ordner erstellen';
$l["to"]='An';
$l["downloadAllAsZip"]='Alles als ZIP-Datei herunterladen';
$l["body"]='Inhalt (Body)';
$l["recievedBefore"]='Empfangen vor';
$l["recievedSince"]='Empfangen seit';
$l["answered"]='Beantwortet';
$l["unanswered"]='Unbeantwortet';
$l["viewed"]='Geöffnet';
$l["outgoingMail"]='Postausgang';
$l["encryption"]='Verschlüsselung';
$l["type"]='Typ';
$l["noEncryption"]='Keine Verschlüsselung';
$l["noAccountTitle"]='Kein E-Mail-Konto';
$l["priority"]='Priorität';
$l["read"]='Gelesen';
$l["NA"]='N/A';
$l["emptyFolder"]='Ordner leeren';
$l["emptyFolderConfirm"]='Möchten Sie den Ordner \'{name}\' wirklich leeren ?';
$l["addUnknownRecipients"]='Unbekannten Empfänger hinzufügen';
$l["addUnknownRecipientsText"]='Sie haben eine Nachricht zu einem/mehreren Empfängern gesendet, der/die nicht in Ihrem Adressbuch sind. Klicken Sie auf einen Namen, wenn Sie diesen zu Ihrem Adressbuch hinzufügen möchten oder schließen Sie dieses Fenster.';
$l["attachFilesPC"]='Vom PC hochladen';
$l["attachFilesGO"]='Aus {product_name}-Dateiablage hinzufügen';
$l["renameFolder"]='Ordner umbenennen';
$l["vacation"]='Automatische Antwort';
$l["vacationActive"]='Automatische Antwort aktivieren';
$l["vacationSubject"]='Betreff';
$l["vacationBody"]='Inhalt';
$l["addToRecipients"]='Zu Empfänger hinzufügen';
$l["addToCC"]='Zu CC hinzufügen';
$l["addToBCC"]='Zu BCC hinzufügen';
$l["viewSource"]='Quelltext anzeigen';
$l["sendNotification"]='%s - Der Sender hat eine Lesebestätigung angefordert. Möchten Sie dies zulassen?';
$l["searchOnSender"]='Nachrichten anzeigen';
$l["blocked"]='{blocked_images} externe Bilder wurden aus Sicherheitsgründen blockiert.';
$l["unblock"]='Zur Ansicht hier klicken';
$l["loadEmailFirst"]='Um diese Funktion zu nutzen, müssen Sie zuerst Ihre Nachrichten mit Klick auf den E-Mail-Tab laden';
$l["confirmEmptySubject"]='Sie haben keinen Betreff eingetragen. Sind Sie sicher, dass Ihre Nachricht ohne Betreff gesendet werden soll?';
$l["usage"]='Belegter Speicherplatz';
$l["searchGO"]='{product_name} durchsuchen';
$l["toggleWindowPosition"]='Nachrichtenansicht umschalten';
$l["closeUploadDialog"]='Schließen Sie zuerst den Upload-Dialog oder warten Sie, bis der Upload beendet ist';
$l["signature"]='Signatur';
$l['defaultProgram']='Standard E-Mail-Programm';
$l['defaultProgramInstructions'] ='<p>Um {product_name} als Ihr Standard E-Mail-Programm einzurichten, lesen Sie bitte <a class="normal-link" href="http://www.{product_name}.com/wiki/E-mail#Set_{product_name}_as_your_default_e-mail_client" target="_blank">diese Anweisungen</a>.</p><p>Unter Windows müssen Sie dann noch <a class="normal-link" href="{url}">diese Regdatei</a> herunterladen und ausführen/importieren</p>';
$l["htmlMarkup"]='HTML-Formatierung verwenden';
$l["confirmLostChanges"]='Änderungen werden verloren gehen. Sind Sie sicher?';
$l["alias"]='Alias';
$l["aliases"]='Aliase';
$l["accountId"]='Konten-ID';
$l["email"]='E-Mail';
$l["manageAliases"]='Aliase...';
$l["addSendersTo"]='Absender als Empfänger';
$l["defaultTemplate"]='Gewählte Vorlage als Standard verwenden';
$l["moving"]='Verschiebe...';
$l["orderFilters"]='Sie können die Reihenfolge der Filter durch ziehen und ablegen verändern.';
$l["orderAccounts"]='Sie können die Reihenfolge der Konten durch ziehen und ablegen verändern.';
$l["groups"]='Gruppen';
$l["showUnread"]='Zeige ungelesene Nachrichten';
$l["searchFrom"]='Absender';
$l["searchTo"]='Empfänger';
$l["searchCC"]='Empfänger (CC)';
$l["youHaveNewMails"]= 'Sie haben {new} neue Nachricht(en)';
$l["anyField"]='Alle Felder';
$l["sending"]='Sende...';
$l["replaceEmailText"]='Dieser Kontakt hat bereits 3 E-Mail Adressen gespeichert. Sie können unten die E-Mail Adresse auswählen die Sie ersetzen wollen.';
$l["skipUnknownRecipientsAction"]='Dieses Fenster nicht mehr anzeigen';
$l["skipUnknownRecipients"]='Dialog zur Aufnahme unbekannter Absender in das Adressbuch nicht anzeigen';
$l["alwaysRequestNotification"]='Immer eine Lesebestätigung anfordern';
$l["alwaysRespondToNotifications"]='Immer auf eine Lesebestätigung antworten';
$l["icalendarUpdateEvent"]='Termin aktualisieren';
$l["icalendarDeleteEvent"]='Termin löschen';
$l["icalendarAcceptInvitation"]='Annehmen';
$l["icalendarDeclineInvitation"]='Ablehnen';
$l["icalendarTentativeInvitation"]='Vorläufig';
$l["icalendarEventUpdated"]='Termin wurde aktualisiert.';
$l["icalendarEventCreated"]='Termin wurde erstellt.';
$l["icalendarEventDeleted"]='Termin wurde gelöscht.';
$l["icalendarInvitationDeclined"]='Einladung wurde abgelehnt.';
$l["icalendarDeleteEventConfirm"]='Sind Sie sicher, dass Sie diesen Termin löschen wollen?';
$l["defaultFontSize"]= 'Standardschriftgröße';
$l["shareFolder"]= 'Freigeben';
$l["readPerm"]='Lesen';
$l["writePerm"]='Schreiben';
$l["deletePerm"]='Löschen';
$l["createMailboxPerm"]='Ordner erstellen';
$l["deleteMailboxPerm"]='Ordner löschen';
$l["adminPerm"]='Verwalten';

$l['name']='E-Mail';
$l['description']='Modul zum Verwalten von E-Mail-Konten und -Nachrichten';
$lang['link_type'][9]='E-Mail';
$l['feedbackNoReciepent']='Sie haben keinen Empfänger eingegeben';
$l['feedbackSMTPProblem']='Es gab ein Problem bei der SMTP-Kommunikation: ';
$l['feedbackUnexpectedError']='Es gab ein unerwartetes Problem bei Erstellung der Nachricht: ';
$l['feedbackCreateFolderFailed']='Ordner erstellen fehlgeschlagen';
$l['feedbackDeleteFolderFailed']='Ordner löschen fehlgeschlagen';
$l['feedbackSubscribeFolderFailed']='Ordner abonnieren fehlgeschlagen';
$l['feedbackUnsubscribeFolderFailed']='Abonnement aufheben fehlgeschlagen';
$l['feedbackCannotConnect']='Es konnte keine Verbindung zu %1$s erstellt werden<br /><br />Der Mailserver hat folgende Antwort gesandt: %2$s';
$l['inbox']='Eingang';
$l['spam']='Spam';
$l['trash']='Papierkorb';
$l['sent']='Gesendet';
$l['drafts']='Entwürfe';
$l['no_subject']='Kein Betreff';
$l['to']='An';
$l['from']='Von';
$l['subject']='Betreff';
$l['no_recipients']='Verborgene Empfänger';
$l['original_message']='--- Original Nachricht ---';
$l['attachments']='Anhänge';
$l['notification_subject']='Gelesen: %s';
$l['notification_body']='Ihre Nachricht mit dem Betreff "%s" wurde am %s geöffnet';
$l['errorGettingMessage']='Nachricht konnte vom Server nicht empfangen werden';
$l['no_recipients_drafts']='Keine Empfänger';
$l['usage_limit']='%s von %s genutzt';
$l['usage']='%s genutzt';
$l['event']='Termin';
$l['calendar']='Kalender';
$l['quotaError']='Ihre Mailbox ist voll. Leeren Sie zuerst ihren Papierkorb. Bleibt dies erfolglos, so deaktivieren Sie den Papierkorb, um Nachrichten aus anderen Ordnern zu löschen. Sie deaktivieren den Papierkorb über:\n\nEinstellungen -> E-Mail-Konten -> Doppelklick auf das gewünschte E-Mail-Konto -> Ordner.';
$l['draftsDisabled']='Die Nachricht konnte nicht gespeichert werden, da der Ordner \'Entwürfe\' (Drafts) nicht aktiviert wurde.<br /><br />Gehen Sie zu E-Mail -> Verwaltung -> Konten -> Doppelklick auf das gewünschte E-Mail-Konto -> Ordner, um den Ordner zu aktivieren.';
$l['noSaveWithPop3']='Die Nachricht konnte nicht gespeichert werden, da ein POP3-Konto diese Funktion nicht unterstützt.';
$l['goAlreadyStarted']='GroupOffice wurde bereits gestartet. Die E-Mail-Oberfläche wird nun in GroupOffice geladen. Schließen Sie dieses Fenster und schreiben Sie Ihre Nachricht in GroupOffice.';
$l['replyHeader']='Am %s, den %s um %s schrieb %s:';
$l['alias']='Alias';
$l['aliases']='Aliase';
$l['noUidNext']='Ihr Mailserver unterstützt kein UIDNEXT. Der Ordner \'Entwürfe\' (Drafts) wurde daher automatisch für dieses E-Mail-Konto deaktiviert.';
$l['disable_trash_folder']='Die Nachricht konnte nicht in den Papierkorb verschoben werden. Vielleicht ist der Ihnen zugewiesene Festplattenspeicher voll. Sie können versuchen Speicher freizumachen, indem Sie den gesamten Papierkorb unter Administration -> Accounts -> Doppelklick auf Ihren Account -> Ordner vorübergehend deaktivieren';
$l['error_move_folder']='Der Ordner konnte nicht verschoben werden';
$l['error_getaddrinfo']='Angegebene Hostadresse ist ungültig';
$l['error_authentication']='Benutzername oder Passwort sind falsch';
$l['error_connection_refused']='Die Verbindung wurde abgebrochen. Bitte überprüfen Sie den Host und die Portnummer.';
$l['iCalendar_event_invitation']='Diese Nachricht enthält eine Termineinladung.';
$l['iCalendar_event_not_found']='Diese Nachricht enthält eine Aktualisierung zu einem nicht mehr vorhandenem Termin.';
$l['iCalendar_update_available']='Diese Nachricht enthält eine Aktualisierung eines existierenden Termins.';
$l['iCalendar_update_old']='Diese Nachricht enthält einen Termin, der bereits verarbeitet wurde.';
$l['iCalendar_event_cancelled']='Diese Nachricht enthält die Absage eines Termins.';
$l['iCalendar_event_invitation_declined']='Diese Nachricht enthält einen Termin den sie abgelehnt haben.';

==> groupoffice-com-4.0.97.tar.gz: groupoffice-com-4.0.97/modules/email/language/de.php <==
<?php

$l["forwardTo"]='Nachricht weiterleiten an';
$l["messages"]='Nachrichten';
$l["message"]='Nachricht';
$l["inbox"]='Eingang';
$l["accounts"]='E-Mail-Konten';
$l["account"]='E-Mail-Konto';
$l["crossAccountMove"]='Es ist nicht möglich, Nachrichten von einem zu einem anderen E-Mail-Konto zu verschieben!';
$l["compose"]='Erstellen';
$l["reply"]='Antworten';
$l["replyAll"]='Allen antworten';
$l["forward"]='Weiterleiten';
$l["markAsRead"]='Als gelesen markieren';
$l["markAsUnread"]='Als ungelesen markieren';
$l["flag"]='Markierung hinzufügen';
$l["unflag"]='Markierung löschen';
$l["flagged"]='Markiert';
$l["unflagged"]='Unmarkiert';
$l["root"]='/';
$l["folders"]='Ordner';
$l["filter"]='Regel';
$l["filters"]='Regeln';
$l["selectFolderDelete"]='Markieren Sie den Ordner, der gelöscht werden soll';
$l["selectFolderAdd"]='Markieren Sie aus der Liste einen Ordner, dem ein Unterordner hinzufügt werden soll. Klicken Sie dann auf \'Neuen Ordner erstellen\'';
$l["selectFolderRename"]='Markieren Sie den Ordner, der umbenannt werden soll';
$l["forward"]='Weiterleiten';
$l["resetSearch"]='Suche zurücksetzen';
$l["emailMessage"]='Nachricht';
$l["host"]='Host';
$l["field"]='Kopfzeile';
$l["contains"]='Enthält';
$l["moveToFolder"]='Verschiebe nach';
$l["incomingMail"]='Posteingang';
$l["advanced"]='Erweitert';
$l["ssl"]='SSL';
$l["tls"]='TLS';
$l["novalidateCert"]='Zertifikat nicht überprüfen';
$l["port"]='Port';
$l["rootMailbox"]='Root (/)';
$l["manageFolders"]='Ordner verwalten';
$l["sendItemsFolder"]='Gesendet';
$l["trashFolder"]='Papierkorb';
$l["draftsFolder"]='Entwürfe ';
$l["sender"]='Von';
$l["subject"]='Betreff';
$l["toField"]='An';
$l["ccField"]='CC';
$l["bccField"]='BCC';
$l["keyword"]='Enthält';
$l["notification"]='Lesebestätigung anfordern';
$l["high"]='Hoch';
$l["normal"]='Normal';
$l["low"]='Niedrig';
$l["from"]='Von';
$l["sendTo"]='Empfänger';
$l["cc"]='CC';
$l["bcc"]='BCC';
$l["selectTemplate"]='Vorlage auswählen';
$l["composeEmail"]='Nachricht schreiben';
$l["send"]='Senden';
$l["extraOptions"]='Zusatzoptionen';
$l["attachments"]='Anhänge';
$l["show"]='Ansicht';
$l["noAccount"]='Sie haben kein E-Mail-Konto konfiguriert. Gehen Sie auf Administration -> E-Mail-Konten, um dies nachzuholen';
$l["attachFiles"]='Dateien anhängen';
$l["uploadAttachments"]='Anhänge hochladen';
$l["startTransfer"]='Transfer beginnen';
$l["cantEditFolder"]='Sie können diesen Ordner nicht bearbeiten';
$l["cantDeleteInboxFolder"]='Sie können den Ordner INBOX (/) nicht löschen';
$l["cantRenameInboxFolder"]='Sie können den Ordner INBOX (/) nicht umbenennen';
$l["enterFolderName"]='Geben Sie einen Ordnernamen ein:';
$l["addFolder"]='Neuen Ordner erstellen';
$l["to"]='An';
$l["downloadAllAsZip"]='Alles als ZIP-Datei herunterladen';
$l["body"]='Inhalt (Body)';
$l["recievedBefore"]='Empfangen vor';
$l["recievedSince"]='Empfangen seit';
$l["answered"]='Beantwortet';
$l["unanswered"]='Unbeantwortet';
$l["viewed"]='Geöffnet';
$l["outgoingMail"]='Postausgang';
$l["encryption"]='Verschlüsselung';
$l["type"]='Typ';
$l["noEncryption"]='Keine Verschlüsselung';
$l["noAccountTitle"]='Kein E-Mail-Konto';
$l["priority"]='Priorität';
$l["read"]='Gelesen';
$l["NA"]='N/A';
$l["emptyFolder"]='Ordner leeren';
$l["emptyFolderConfirm"]='Möchten Sie den Ordner \'{name}\' wirklich leeren ?';
$l["addUnknownRecipients"]='Unbekannten Empfänger hinzufügen';
$l["addUnknownRecipientsText"]='Sie haben eine Nachricht zu einem/mehreren Empfängern gesendet, der/die nicht in Ihrem Adressbuch sind. Klicken Sie auf einen Namen, wenn Sie diesen zu Ihrem Adressbuch hinzufügen möchten oder schließen Sie dieses Fenster.';
$l["attachFilesPC"]='Vom PC hochladen';
$l["attachFilesGO"]='Aus {product_name}-Dateiablage hinzufügen';
$l["renameFolder"]='Ordner umbenennen';
$l["vacation"]='Automatische Antwort';
$l["vacationActive"]='Automatische Antwort aktivieren';
$l["vacationSubject"]='Betreff';
$l["vacationBody"]='Inhalt';
$l["addToRecipients"]='Zu Empfänger hinzufügen';
$l["addToCC"]='Zu CC hinzufügen';
$l["addToBCC"]='Zu BCC hinzufügen';
$l["viewSource"]='Quelltext anzeigen';
$l["sendNotification"]='%s - Der Sender hat eine Lesebestätigung angefordert. Möchten Sie dies zulassen?';
$l["searchOnSender"]='Nachrichten anzeigen';
$l["blocked"]='{blocked_images} externe Bilder wurden aus Sicherheitsgründen blockiert.';
$l["unblock"]='Zur Ansicht hier klicken';
$l["loadEmailFirst"]='Um diese Funktion zu nutzen, müssen Sie zuerst Ihre Nachrichten mit Klick auf den E-Mail-Tab laden';
$l["confirmEmptySubject"]='Sie haben keinen Betreff eingetragen. Sind Sie sicher, dass Ihre Nachricht ohne Betreff gesendet werden soll?';
$l["usage"]='Belegter Speicherplatz';
$l["searchGO"]='{product_name} durchsuchen';
$l["toggleWindowPosition"]='Nachrichtenansicht umschalten';
$l["closeUploadDialog"]='Schließen Sie zuerst den Upload-Dialog oder warten Sie, bis der Upload beendet ist';
$l["signature"]='Signatur';
$l["defaultProgram"]='Standard E-Mail-Programm';
$l["defaultProgramInstructions"] ='<p>Um {product_name} als Ihr Standard E-Mail-Programm einzurichten, lesen Sie bitte <a class="normal-link" href="http://www.{product_name}.com/wiki/E-mail#Set_{product_name}_as_your_default_e-mail_client" target="_blank">diese Anweisungen</a>.</p><p>Unter Windows müssen Sie dann noch <a class="normal-link" href="{url}">diese Regdatei</a> herunterladen und ausführen/importieren</p>';
$l["htmlMarkup"]='HTML-Formatierung verwenden';
$l["confirmLostChanges"]='Änderungen werden verloren gehen. Sind Sie sicher?';
$l["alias"]='Alias';
$l["aliases"]='Aliase';
$l["accountId"]='Konten-ID';
$l["email"]='E-Mail';
$l["manageAliases"]='Aliase...';
$l["addSendersTo"]='Absender als Empfänger';
$l["defaultTemplate"]='Gewählte Vorlage als Standard verwenden';
$l["moving"]='Verschiebe...';
$l["orderFilters"]='Sie können die Reihenfolge der Filter durch ziehen und ablegen verändern.';
$l["orderAccounts"]='Sie können die Reihenfolge der Konten durch ziehen und ablegen verändern.';
$l["groups"]='Gruppen';
$l["showUnread"]='Zeige ungelesene Nachrichten';
$l["searchFrom"]='Absender';
$l["searchTo"]='Empfänger';
$l["searchCC"]='Empfänger (CC)';
$l["youHaveNewMails"]= 'Sie haben {new} neue Nachricht(en)';
$l["anyField"]='Alle Felder';
$l["sending"]='Sende...';
$l["replaceEmailText"]='Dieser Kontakt hat bereits 3 E-Mail Adressen gespeichert. Sie können unten die E-Mail Adresse auswählen die Sie ersetzen wollen.';
$l["skipUnknownRecipientsAction"]='Dieses Fenster nicht mehr anzeigen';
$l["skipUnknownRecipients"]='Dialog zur Aufnahme unbekannter Absender in das Adressbuch nicht anzeigen';
$l["alwaysRequestNotification"]='Immer eine Lesebestätigung anfordern';
$l["alwaysRespondToNotifications"]='Immer auf eine Lesebestätigung antworten';
$l["icalendarUpdateEvent"]='Termin aktualisieren';
$l["icalendarDeleteEvent"]='Termin löschen';
$l["icalendarAcceptInvitation"]='Annehmen';
$l["icalendarDeclineInvitation"]='Ablehnen';
$l["icalendarTentativeInvitation"]='Vorläufig';
$l["icalendarEventUpdated"]='Termin wurde aktualisiert.';
$l["icalendarEventCreated"]='Termin wurde erstellt.';
$l["icalendarEventDeleted"]='Termin wurde gelöscht.';
$l["icalendarInvitationDeclined"]='Einladung wurde abgelehnt.';
$l["icalendarDeleteEventConfirm"]='Sind Sie sicher, dass Sie diesen Termin löschen wollen?';
$l["defaultFontSize"]= 'Standardschriftgröße';
$l["shareFolder"]= 'Freigeben';
$l["readPerm"]='Lesen';
$l["writePerm"]='Schreiben';
$l["deletePerm"]='Löschen';
$l["createMailboxPerm"]='Ordner erstellen';
$l["deleteMailboxPerm"]='Ordner löschen';
$l["adminPerm"]='Verwalten';

$l['name']='E-Mail';
$l['description']='Modul zum Verwalten von E-Mail-Konten und -Nachrichten';
$lang['link_type'][9]='E-Mail';
$l['feedbackNoReciepent']='Sie haben keinen Empfänger eingegeben';
$l['feedbackSMTPProblem']='Es gab ein Problem bei der SMTP-Kommunikation: ';
$l['feedbackUnexpectedError']='Es gab ein unerwartetes Problem bei Erstellung der Nachricht: ';
$l['feedbackCreateFolderFailed']='Ordner erstellen fehlgeschlagen';
$l['feedbackDeleteFolderFailed']='Ordner löschen fehlgeschlagen';
$l['feedbackSubscribeFolderFailed']='Ordner abonnieren fehlgeschlagen';
$l['feedbackUnsubscribeFolderFailed']='Abonnement aufheben fehlgeschlagen';
$l['feedbackCannotConnect']='Es konnte keine Verbindung zu %1$s erstellt werden<br /><br />Der Mailserver hat folgende Antwort gesandt: %2$s';
$l['inbox']='Eingang';
$l['spam']='Spam';
$l['trash']='Papierkorb';
$l['sent']='Gesendet';
$l['drafts']='Entwürfe';
$l['no_subject']='Kein Betreff';
$l['to']='An';
$l['from']='Von';
$l['subject']='Betreff';
$l['no_recipients']='Verborgene Empfänger';
$l['original_message']='--- Original Nachricht ---';
$l['attachments']='Anhänge';
$l['notification_subject']='Gelesen: %s';
$l['notification_body']='Ihre Nachricht mit dem Betreff "%s" wurde am %s geöffnet';
$l['errorGettingMessage']='Nachricht konnte vom Server nicht empfangen werden';
$l['no_recipients_drafts']='Keine Empfänger';
$l['usage_limit']='%s von %s genutzt';
$l['usage']='%s genutzt';
$l['event']='Termin';
$l['calendar']='Kalender';
$l['quotaError']='Ihre Mailbox ist voll. Leeren Sie zuerst ihren Papierkorb. Bleibt dies erfolglos, so deaktivieren Sie den Papierkorb, um Nachrichten aus anderen Ordnern zu löschen. Sie deaktivieren den Papierkorb über:\n\nEinstellungen -> E-Mail-Konten -> Doppelklick auf das gewünschte E-Mail-Konto -> Ordner.';
$l['draftsDisabled']='Die Nachricht konnte nicht gespeichert werden, da der Ordner \'Entwürfe\' (Drafts) nicht aktiviert wurde.<br /><br />Gehen Sie zu E-Mail -> Verwaltung -> Konten -> Doppelklick auf das gewünschte E-Mail-Konto -> Ordner, um den Ordner zu aktivieren.';
$l['noSaveWithPop3']='Die Nachricht konnte nicht gespeichert werden, da ein POP3-Konto diese Funktion nicht unterstützt.';
$l['goAlreadyStarted']='GroupOffice wurde bereits gestartet. Die E-Mail-Oberfläche wird nun in GroupOffice geladen. Schließen Sie dieses Fenster und schreiben Sie Ihre Nachricht in GroupOffice.';
$l['replyHeader']='Am %s, den %s um %s schrieb %s:';
$l['alias']='Alias';
$l['aliases']='Aliase';
$l['noUidNext']='Ihr Mailserver unterstützt kein UIDNEXT. Der Ordner \'Entwürfe\' (Drafts) wurde daher automatisch für dieses E-Mail-Konto deaktiviert.';
$l['disable_trash_folder']='Die Nachricht konnte nicht in den Papierkorb verschoben werden. Vielleicht ist der Ihnen zugewiesene Festplattenspeicher voll. Sie können versuchen Speicher freizumachen, indem Sie den gesamten Papierkorb unter Administration -> Accounts -> Doppelklick auf Ihren Account -> Ordner vorübergehend deaktivieren';
$l['error_move_folder']='Der Ordner konnte nicht verschoben werden';
$l['error_getaddrinfo']='Angegebene Hostadresse ist ungültig';
$l['error_authentication']='Benutzername oder Passwort sind falsch';
$l['error_connection_refused']='Die Verbindung wurde abgebrochen. Bitte überprüfen Sie den Host und die Portnummer.';
$l['iCalendar_event_invitation']='Diese Nachricht enthält eine Termineinladung.';
$l['iCalendar_event_not_found']='Diese Nachricht enthält eine Aktualisierung zu einem nicht mehr vorhandenem Termin.';
$l['iCalendar_update_available']='Diese Nachricht enthält eine Aktualisierung eines existierenden Termins.';
$l['iCalendar_update_old']='Diese Nachricht enthält einen Termin, der bereits verarbeitet wurde.';
$l['iCalendar_event_cancelled']='Diese Nachricht enthält die Absage eines Termins.';
$l['iCalendar_event_invitation_declined']='Diese Nachricht enthält einen Termin den sie abgelehnt haben.';
$l["addUnknownSenders"]='Unbekannte Absender hinzufügen';
$l["addUnknownSendersText"]='Sie fügen die ausgewählten Absenderadressen einer Adressliste hinzu. Zuvor müssen die gewählten Absender einem Group-Office-Adressbuch hinzugefügt werden. Klicken Sie auf einen Namen, wenn Sie die Person hinzufügen möchten oder schließen Sie dieses Fenster.';
$l["emailFiles"]='Dateien versenden';
$l["moveOldMails"]= 'Alte E-Mails verschieben';
$l["moveOldMailsInstructions"]= 'Wählen Sie ein Datum. Wenn Sie anschließend OK klicken, werden alle E-Mails im gewählten Ordner vor diesem Datum in den gewählten Zielordner verschoben.';
$l["folder"]= 'Ordner';
$l["moveOldMailsSure"]= 'Möchten Sie alle E-Mails älter als {date} von "{source}" nach "{target}" verschiebe?';
$l["nMovedMailsTxt"]= 'Die Anzahl der verschobenen Nachrichten ist';
$l["deletingEmails"]= 'Lösche E-Mails...';
$l["everythingBefore"]= 'Alle E-Mails vor';
$l["alsoChildren"]= 'Wende dies auch auf die E-Mails in den Unterordnern an.';
$l['autolinked']='Diese Nachricht wurde automatisch nach %s verlinkt';
$l['defaultProgramInstructions']='<p>Um {product_name} als Ihr Standard E-Mail-Programm zu wählen, lesen Sie bitte <a class="normal-link" href="http://www.{product_name}.com/wiki/E-mail#Set_{product_name}_as_your_default_e-mail_client" target="_blank">diese Anleitung</a>.</p><p>Wenn Sie Windows verwenden, müssen Sie dann noch <a class="normal-link" href="{url}">diese Regdatei</a>herunterladen und ausführen/importieren</p>';
$l['xssDetected']="Diese Nachricht könnte bösartigen Inhalt enthalten. Klicken Sie hier, um dennoch die gefilterte Nachricht anzusehen.";
$l['xssMessageHidden']='Aus Sicherheitsgründen wurde die Nachricht verborgen';
$l['failedRecipients']='Fehler beim Senden an';
$l['ignoreSentFolder']='Speichere Antworten im gleichen Ordner wie die Originalnachicht';
$l['sourceAndTargetSame']="Quell- und Zielmailbox scheinen nicht identisch zu sein";
$l['subscribeFolders']='Ordner abonnieren';
$l['imapLoginFailed']='Authentifikation für den Nutzer "%username" fehlgeschlagen.';
$l['tryNewCredentials']='Versuchen Sie ein alternatives IMAP-Kennwort einzugeben.';
$l['moveTo']='Verschiebe nach';
